@@ -18,7 +18,7 @@ import traceback
 import urllib, os, socket, time
 
 from twisted.web2 import http, responsecode
-from twisted.web2.http_headers import Cookie as TwCookie, MimeType
+from twisted.web2.http_headers import Cookie as MimeType
 from twisted.web2.resource import PostableResource
 from twisted.internet.threads import callMultipleInThread
 from twisted.python import failure
@@ -35,9 +35,10 @@ from saml_utils import (encode_request, gen_metadata, get_endpoint,
                         process_auth_request, process_assertion,
                         encode_idp_cookie, split_form_arg)
 from saml2 import samlp
+from oidc_utils import openid_logout_url
 from page import gen_page, trace, log
 from config import (CERTFILE, AUTH_FORM_URL, IDP_IDENTITY, DEFAULT_CSS,
-                    SEND_CAS_LOGOUT, DISPLAY_FEDERATION, DEBUG_LOG, encoding)
+                    SEND_CAS_LOGOUT, DISPLAY_FEDERATION, DEBUG_LOG, encoding, COOKIE_NAME, COOKIE_DOMAIN)
 
 class SamlResource(PostableResource):
 
@@ -99,12 +100,17 @@ class SamlLogout(SamlResource):
         super(SamlLogout, self).__init__()
 
     @trace
-    def send_logout_request(self, saml_identity, sp_meta, user_id, ticket, sso_session, from_url, css):
+    def saml_logout_request(self, ticket, sso_session, from_url, css):
         """Envoi d'une requête de déconnexion à une entité partenaire et stocke les informations sur l'origine de la déconnexion"""
+        saml_identity = ticket.saml_ident
+        saml_role = ticket.saml_role
+        # Lecture des métadonnées du partenaire
+        sp_meta = self.manager.get_metadata(saml_identity)
+        user_id = ticket.name_id
         try:
             binding, service_url, response_url = get_endpoint(sp_meta, 'SingleLogoutService', ticket.saml_role)
         except InternalError:
-            log.msg(_('no usable endpoint for %s') % sp_meta['entityID'])
+            log.msg(_('no usable endpoint for {0}').format(sp_meta['entityID']))
             # store error for display ?
             return None
 
@@ -142,8 +148,44 @@ class SamlLogout(SamlResource):
         # on stocke l'id et le ticket avant de rediriger
         ticket.valid = False
         self.manager.pending_logout[sso_session][3][response_id] = ticket.ticket
+        log.msg("%s -- %s" % (sso_session, _("Sending SAML logout request to {0} ({1}) : {2}").format(saml_identity, service_url, response_id)))
+        return resp
 
-        log.msg("%s -- %s" % (sso_session, _("Sending SAML logout request to %s (%s) : %s") % (saml_identity, service_url, response_id)))
+    @trace
+    def openid_logout_request(self, ticket, sso_session, from_url, css):
+        """Envoi d'une requête de déconnexion à une entité partenaire et stocke les informations sur l'origine de la déconnexion"""
+        # calcul de la requête depuis les infos du ticket
+        state, redirect_url, needs_confirm = openid_logout_url(ticket.provider_data, self.manager, sso_session, from_url)
+        # on stocke l'id et le ticket avant de rediriger
+        ticket.valid = False
+        self.manager.pending_logout[sso_session][3][state] = ticket.ticket
+        if needs_confirm:
+            return self.confirm_logout(redirect_url, ticket, css)
+        else:
+            return RedirectResponse(redirect_url)
+
+    @trace
+    def confirm_logout(self, redirect_url, ticket, css):
+        """ Asks if user wants to disconnect from Provider
+        """
+        prov_label = self.manager.external_providers[ticket.provider_data['provider']][2]
+        content = ""
+        logout_msg = _('Do you want to disconnect from {0} ?').format(prov_label)
+        params = {'logout_url':redirect_url + "?state=%s" % ticket.provider_data['state'],
+                  # fallback url redirects on /logout with state to validate
+                  # that provider was taken into account (even if not disconnected)
+                  'fallback_url':AUTH_FORM_URL + '/logout?state=%s' % ticket.provider_data['state'],
+                  'message':logout_msg
+                 }
+        header_script = """<script type="text/javascript">\n"""
+        header_script += open('interface/scripts/confirm_logout.js').read() % params
+        header_script += """\n</script>"""
+        onload_script = """confirm_logout();"""
+        resp = http.Response(stream = gen_page(_('Logout request to service'), content,
+                                               javascript = onload_script,
+                                               header_script=header_script,
+                                               css=css))
+        resp = self.set_headers(resp)
         return resp
 
     @trace
@@ -154,7 +196,7 @@ class SamlLogout(SamlResource):
                        (versions futures du client CAS ?)
         """
         logoutRequest = saml_message.gen_cas_logout_request(ticket.ticket, use_SOAP)
-        log.msg("%s -- %s" % (sso_session, _("Sending CAS logout request to %s") % ticket.service_url))
+        log.msg("%s -- %s" % (sso_session, _("Sending CAS logout request to {0}").format(ticket.service_url)))
         # gestion du passage ou non par un proxy http si défini pour cette application
         # envoi de la requête
         req = httprequest.HTTPRequest()
@@ -162,14 +204,14 @@ class SamlLogout(SamlResource):
         try:
             req.request(ticket.service_url, {'logoutRequest':logoutRequest})
         except httprequest.RequestError, e:
-            log.msg("%s -- %s" % (ticket.session_id, _('Error sending logout request to %s : ' \
-                    % (ticket.service_url,))))
+            log.msg("%s -- %s" % (ticket.session_id, _('Error sending logout request to {0} : ')\
+                    .format(ticket.service_url)))
             log.msg(str(e))
         # retour en mode sans proxy
         self.manager.set_urllib_proxy()
 
     @trace
-    def process_logout_response(self, request, sso_session):
+    def saml_logout_response(self, request, sso_session):
         """traite une réponse de déconnexion et met à jour les tickets correspondants dans le gestionnaire de sessions
         """
         signature_ok, saml_resp = extract_message(request, 'SAMLResponse')
@@ -180,7 +222,7 @@ class SamlLogout(SamlResource):
         msg_id = response.id
         if self.manager.replayed_saml_msg(msg_id):
             # page d'erreur
-            raise InternalError("%s -- %s" % (sso_session, _('response message has been replayed (%s)') % msg_id))
+            raise InternalError("%s -- %s" % (sso_session, _('response message has been replayed ({0})').format(msg_id)))
         resp_issuer = response.issuer.text.encode(encoding)
         in_response_to = response.in_response_to
         # Vérification de l'existence de la requête spécifiée dans in_response_to
@@ -189,7 +231,7 @@ class SamlLogout(SamlResource):
             raise InternalError("%s : %s" % (_('corresponding request not found'), in_response_to))
         orig_message_data = self.manager.get_saml_msg(in_response_to)
         if orig_message_data.get('response_id', None) is not None:
-            raise InternalError((_('response already received for request %s') % in_response_to))
+            raise InternalError((_('response already received for request {0}').format(in_response_to)))
         #issue_instant = date_from_string(response.issue_instant)
         status_code = response.status.status_code.value
         #if response.status.status_message is not None:
@@ -199,7 +241,22 @@ class SamlLogout(SamlResource):
             self.manager.pending_logout[sso_session][1].append(ticket_id)
         # on indique que le message d'origine a  reçu une réponse
         self.manager.update_saml_msg(in_response_to, {'response_id':msg_id})
-        log.msg("%s -- %s" % (sso_session, _('SAMLResponse (%s) received from %s in response to %s') % ('LogoutResponse', resp_issuer, in_response_to)))
+        log.msg("%s -- %s" % (sso_session, _('SAMLResponse ({0}) received from {1} in response to {2}').format('LogoutResponse', resp_issuer, in_response_to)))
+
+    @trace
+    def openid_logout_response(self, request, sso_session):
+        """traite une réponse de déconnexion et met à jour les tickets correspondants dans le gestionnaire de sessions
+        """
+        in_response_to = request.args['state'][0]
+        # Vérification de l'existence de la requête spécifiée dans in_response_to
+        if in_response_to not in self.manager.pending_logout[sso_session][3]:
+            # FIXME TODO: generate a saml negative saml response
+            raise InternalError("%s : %s" % (_('corresponding request not found'), in_response_to))
+        # le choix de la fermeture de session est à la discrétion de l'utilisateur,
+        # dans tous les cas, on considère la demande traitée
+        ticket_id = self.manager.pending_logout[sso_session][3][in_response_to]
+        self.manager.pending_logout[sso_session][1].append(ticket_id)
+        log.msg("%s -- %s" % (sso_session, _('OpenID logout performed in response to {0}').format(in_response_to)))
 
     @trace
     def build_logout_error(self, err_infos, sso_session, relay_state, css):
@@ -219,7 +276,7 @@ class SamlLogout(SamlResource):
         except InternalError:
             traceback.print_exc()
             # on ne sait pas où la réponse doit être envoyée
-            err_msg = _('no usable endpoint for %s') % req_issuer
+            err_msg = _('no usable endpoint for {0}').format(req_issuer)
             return http.Response(stream = gen_page(_('Logout Error'), err_msg, css))
         # Envoi de la réponse à l'émetteur de la requête
         response_id = self.manager.gen_saml_id({'type':'LogoutResponse'})
@@ -264,27 +321,28 @@ class SamlLogout(SamlResource):
             if app_ticket in self.manager.saml_sessions:
                 # session définie par l'idp distant -> on récupère l'app_ticket local correspondant
                 app_ticket = self.manager.saml_sessions[app_ticket]
-            if app_ticket in self.manager.app_sessions:
+            if self.manager._DBAppSessionFromTicket(app_ticket):
                 ticket = self.manager.app_sessions[app_ticket]
                 if saml_req.session_index:
                     if ticket.session_id == sso_session:
                         if req_issuer != ticket.saml_ident:
-                            raise InternalError(_('logout requester (%s) does not own session') % req_issuer)
+                            raise InternalError(_('logout requester ({0}) does not own session').format(req_issuer))
                     # vérification du nameid
                     if (ticket.name_id != req_name_id):
                         raise InternalError(_('logout request for invalid session'))
                     # début d'un logout initié par un participant de la session
                     self.manager.pending_logout[sso_session] = [samlp.STATUS_SUCCESS, [app_ticket], (app_ticket, req_id, req_issuer), {}, [], None]
+                    self.manager._DBInitLogout(sso_session)
                     # on définit le ticket comme non valide
                     ticket.valid = False
                 else:
                     raise InternalError(_('logout request for invalid session'))
             else:
                 raise InternalError(_('Invalid session'))
-            log.msg("%s -- %s" % (sso_session, _('SAMLRequest (%s) received from %s') % ('LogoutRequest', req_issuer)))
+            log.msg("%s -- %s" % (sso_session, _('SAMLRequest ({0}) received from {1}').format('LogoutRequest', req_issuer)))
         except InternalError, msg:
             # On stocke les informations nécessaires à la génération du message d'erreur
-            log.msg("%s -- %s" % (sso_session, _('Invalid SAMLRequest (%s) received from %s') % ('LogoutRequest', req_issuer)))
+            log.msg("%s -- %s" % (sso_session, _('Invalid SAMLRequest ({0}) received from {1}').format('LogoutRequest', req_issuer)))
             return False, (req_id, req_issuer, str(msg))
         return True , sso_session
 
@@ -301,29 +359,39 @@ class SamlLogout(SamlResource):
         logout_call_list = []
         # on regarde si le logout a été initié par requête d'une entité partenaire
         if self.manager.pending_logout[sso_session][2]:
-            req_ticket, req_id, req_issuer  = self.manager.pending_logout[sso_session][2]
+            req_ticket, req_id, req_issuer = self.manager.pending_logout[sso_session][2]
         else:
             req_ticket = req_id = req_issuer = None
-
         for ticket in self.manager.user_app_tickets[sso_session]:
             if hasattr(ticket,'saml_ident'):
                 if ticket.ticket != req_ticket:
                     if ticket.valid:
-                        # ticket correspondant à une session 'saml' valide
-                        # -> Envoi d'une demande de déconnexion auprès de l'entité partenaire
-                        saml_identity = ticket.saml_ident
-                        saml_role = ticket.saml_role
-                        # Lecture des métadonnées du partenaire
-                        sp_meta = self.manager.get_metadata(saml_identity)
-                        user_id = ticket.name_id
-                        return self.send_logout_request(saml_identity, sp_meta, user_id, ticket, sso_session, from_url, css)
+                        if hasattr(ticket, 'provider_data'):
+                            # ticket correspondant à une session initiée par un provider OpenID connu
+                            client = self.manager.external_providers[ticket.provider_data['provider']][0]
+                            if not client.can_logout:
+                                # si la déconnexion n'est pas gérée, on passe au ticket suivant
+                                self.manager.pending_logout[sso_session][1].append(ticket.ticket)
+                                ticket.valid = False
+                                continue
+                            else:
+                                # sinon demande de déconnexion auprès du fournisseur
+                                return self.openid_logout_request(ticket, sso_session, from_url, css)
+                        else:
+                            # ticket correspondant à une session 'saml' valide
+                            # -> Envoi d'une demande de déconnexion auprès de l'entité partenaire
+                            return self.saml_logout_request(ticket, sso_session, from_url, css)
                     else:
                         # Une déconnexion a déjà été demandée pour ce ticket
                         # -> On met à jour le status du logout en cours
-                        if ticket.ticket in self.manager.pending_logout[sso_session][1]:
-                            closed_services.append(ticket.saml_ident)
+                        if ticket.saml_ident in self.manager.external_providers:
+                            service_name = self.manager.external_providers[ticket.saml_ident][2]
                         else:
-                            failed_services.append(ticket.saml_ident)
+                            service_name = ticket.saml_ident
+                        if ticket.ticket in self.manager.pending_logout[sso_session][1]:
+                            closed_services.append(service_name)
+                        else:
+                            failed_services.append(service_name)
                             # Au moins une des demandes envoyées n'a pas reçu de réponse favorable (logout partiel)
                             self.manager.pending_logout[sso_session][0] = samlp.STATUS_PARTIAL_LOGOUT
             else:
@@ -359,8 +427,7 @@ class SamlLogout(SamlResource):
             binding, service_url, response_url = get_endpoint(sp_meta, 'SingleLogoutService', saml_role)
         except InternalError:
             traceback.print_exc()
-            #XXX FIXME
-            err_msg = _('no usable endpoint for %s') % req_issuer
+            err_msg = _('no usable endpoint for {0}').format(req_issuer)
             return http.Response(stream = gen_page(_('Logout Error'), err_msg, css))
         # Envoi de la réponse finale à l'émetteur de la requête
         response_id = self.manager.gen_saml_id({'type':'LogoutResponse'})
@@ -396,7 +463,7 @@ class SamlLogout(SamlResource):
             """ % (response_url, split_form_arg(response), relay_info, sign_method, _('Logout confirmation to service'))
             resp = http.Response(stream = gen_page(_('Logout confirmation to service'), form, css))
             resp = self.set_headers(resp)
-        log.msg("%s -- %s" % (sso_session, _("SAMLResponse (%s) sent to %s") % ('LogoutResponse', response_url)))
+        log.msg("%s -- %s" % (sso_session, _("SAMLResponse ({0}) sent to {1}").format('LogoutResponse', response_url)))
         return resp
 
     @trace
@@ -439,7 +506,7 @@ class SamlLogout(SamlResource):
         cookies = getCookies(request)
         sso_session = None
         for cookie in cookies:
-            if cookie.name == 'EoleSSOServer':
+            if cookie.name == COOKIE_NAME:
                 sso_session = cookie.value
                 authenticated = self.manager.validate_session(sso_session)
                 break
@@ -485,7 +552,9 @@ class SamlLogout(SamlResource):
             if 'SAMLResponse' in request.args and sso_session in self.manager.pending_logout:
                 # test sur pending logout : hack car dans certains cas firefox semble rejouer une requête de logout
                 # vers le sp sans que l'idp l'aie envoyée
-                self.process_logout_response(request, sso_session)
+                self.saml_logout_response(request, sso_session)
+            if 'state' in request.args and sso_session in self.manager.pending_logout:
+                self.openid_logout_response(request, sso_session)
             if 'SAMLRequest' in request.args:
                 req_ok, err_infos = self.process_logout_request(request, sso_session)
                 if not req_ok:
@@ -494,6 +563,7 @@ class SamlLogout(SamlResource):
             elif sso_session not in self.manager.pending_logout:
                 # Logout initié localement (idp initiated), on conserve une trace de relay_state et from_url
                 # au cas où on aurait des redirections à faire (requêtes SAML)
+                self.manager._DBInitLogout(sso_session)
                 self.manager.pending_logout[sso_session] = [samlp.STATUS_SUCCESS, [], None, {}, [], (from_url, relay_state)]
             # envoi de requêtes de déconnexion pour chaque session attachée à la session SSO
             resp = self.check_attached_sessions(sso_session, closed_services, failed_services, from_url, css)
@@ -530,7 +600,7 @@ class SamlLogout(SamlResource):
                 # Dans le cas ou on doit rediriger et aucune erreur n'est survenue -> pas d'affichage
                 # XXX FIXME : afficher un formulaire d'avertissement dans tous les cas ?
                 resp = RedirectResponse(from_url)
-                log.msg(_("Logged out : redirecting to %s") % from_url)
+                log.msg(_("Logged out : redirecting to {0}").format(from_url))
             elif resp is None:
                 resp = RedirectResponse('/')
 
@@ -585,7 +655,7 @@ class SamlConsumer(SamlResource):
         cookies = getCookies(request)
         sso_session = None
         for cookie in cookies:
-            if cookie.name == 'EoleSSOServer':
+            if cookie.name == COOKIE_NAME:
                 sso_session = cookie.value
                 # On vérifie si la session est valide
                 authenticated = self.manager.validate_session(sso_session)
@@ -629,11 +699,11 @@ class SamlConsumer(SamlResource):
 
         except InternalError, e:
             traceback.print_exc()
-            return self.set_header(gen_page_err(str(e), return_url, css))
+            return self.set_headers(gen_page_err(str(e), return_url, css))
         # l'assertion reçue est valide, on la traite
         if not success:
             content = _('Federation : No local user does match specified attributes')
-            return self.set_header(gen_page_err(content, return_url, css))
+            return self.set_headers(gen_page_err(content, return_url, css))
         else:
             for assertion_id, data in infos.items():
                 # si des attributs sont remontés et valides, on cherche l'utilisateur correspondant (fédération par attribut commun)
@@ -644,7 +714,7 @@ class SamlConsumer(SamlResource):
                     idp_opts = self.manager.get_federation_options(assertion_issuer)
                     if 'default_service' in idp_opts:
                         return_url = idp_opts['default_service']
-                content = u"<h2>%s</h2>" % (_("you have been authenticated by identity provider %s") % assertion_issuer,)
+                content = u"<h2>%s</h2>" % (_("you have been authenticated by identity provider {0}").format(assertion_issuer))
                 # On essaye de créer une session pour l'utilisateur local correspondant (ou on reprend l'existante)
                 if not authenticated:
                     sso_session = None
@@ -652,7 +722,7 @@ class SamlConsumer(SamlResource):
                 # (ex : n°rne présent)
                 defer_federation = self.manager.authenticate_federated_user(resp_attrs, assertion_issuer, auth_instant, class_ref, sso_session)
                 return defer_federation.addBoth(self.callb_federation, return_url, assertion_id, data, content, css, request, cookies)
-            return self.set_header(gen_page_err(_("NO USER FOUND"), return_url, css))
+            return self.set_headers(gen_page_err(_("NO USER FOUND"), return_url, css))
 
     @trace
     def callb_federation(self, result_fed, return_url, assertion_id, data, content, css, request, cookies):
@@ -660,11 +730,7 @@ class SamlConsumer(SamlResource):
         session_index, assertion_issuer, resp_attrs, name_id, auth_instant, class_ref = data
         if session_id and not isinstance(session_id, failure.Failure):
             # Mise en place de cookie SSO pour la session locale
-            cookies = []
-            for cookie in getCookies(request):
-                if cookie.name != 'EoleSSOServer':
-                    cookies.append(cookie)
-            cookies.append(TwCookie("EoleSSOServer", session_id, path = "/", discard=True, secure=True))
+            cookies = self.manager.gen_session_cookies(session_id, cookies)
             # Si une session existe pour ce fournisseur de service, on le supprime
             self.manager.remove_old_ticket(session_id, assertion_issuer)
             # On stocke les informations de session dans un ticket fictif (pour permettre le logout)
@@ -679,7 +745,7 @@ class SamlConsumer(SamlResource):
                                                                   index=endpoint_index)
             except InternalError:
                 # XXX FIXME
-                err_msg = _('no usable endpoint for %s') % assertion_issuer
+                err_msg = _('no usable endpoint for {0}').format(assertion_issuer)
                 log.msg(err_msg)
                 return self.set_headers(http.Response(stream = gen_page(_('Assertion consuming error'), err_msg, css)))
             app_ticket = self.manager.get_app_ticket(session_id, response_url, idp_ident=assertion_issuer)
@@ -704,6 +770,9 @@ class SamlConsumer(SamlResource):
                 if self.manager.app_sessions[app_ticket].timeout_callb.cancelled == 0:
                     # ce ticket expirera seulement à la fermeture de la session SSO
                     self.manager.app_sessions[app_ticket].timeout_callb.cancel()
+                if DEBUG_LOG:
+                    log.msg("[DBSESSION] SAML CALLBACK %s " % app_ticket)
+                self.manager._DBUpdateAppTicket(self.manager.app_sessions[app_ticket])
                 self.manager.saml_sessions[session_index] = app_ticket
             # XXX FIXME : Debug
             if return_url is None:
@@ -721,7 +790,7 @@ class SamlConsumer(SamlResource):
                 log.msg('Failure searching federated_user : %s' % session_id.getErrorMessage())
             content = _('Federation : No local user does match specified attributes')
             resp = gen_page_err(content, return_url, css)
-            return self.set_headers(gen_page_err)
+            return self.set_headers(resp)
         return self.redirect_after_federation(return_url, content, css, cookies)
 
     @trace
@@ -779,7 +848,7 @@ class SamlResponse(SamlResource):
             # stockage temporaire du résultat pour conserver les informations d'origine lorsqu'une redirection
             # sur la page d'authentification est nécessaire
             req_ticket = self.manager.gen_relay_state(request_data)
-            log.msg("%s : %s" % (_('SAMLRequest (%s) received from %s') % ('AuthnRequest', sp_ident), req_id))
+            log.msg("%s : %s" % (_('SAMLRequest ({0}) received from {1}').format('AuthnRequest', sp_ident), req_id))
             sp_meta = self.manager.get_metadata(sp_ident)
             # on vérifie que l'on est capable de gérer le niveau de sécurité demandé (requested_context)
             if requested_contexts:
@@ -811,7 +880,7 @@ class SamlResponse(SamlResource):
                     binding, service_url, response_url = get_endpoint(sp_meta, 'AssertionConsumerService', index=endpoint_index)
                 except InternalError:
                     traceback.print_exc()
-                    err_msg = _('no usable endpoint for %s') % sp_ident
+                    err_msg = _('no usable endpoint for {0}').format(sp_ident)
                     resp = http.Response(stream = gen_page(_('Unreachable resource'), err_msg, css))
                     return self.set_headers(resp)
             else:
@@ -828,7 +897,7 @@ class SamlResponse(SamlResource):
         cookies = getCookies(request)
         from_credentials = False
         for cookie in cookies:
-            if cookie.name == 'EoleSSOServer':
+            if cookie.name == COOKIE_NAME:
                 session_id = cookie.value
                 # vérification de la validité de la session
                 authenticated = self.manager.validate_session(session_id)
@@ -976,7 +1045,7 @@ class SamlResponse(SamlResource):
 <FORM name="federate_user" action="%s" method="POST" onSubmit="return aff_wait()">
 <input type="hidden" name="SAMLResponse" value="%s">
 %s
-<input type="hidden" name="SigAlg" value="%s">
+<input type="hidden" xx name="SigAlg" value="%s">
 %s
 </FORM>""" % (msg, response_url, response, relay_info, sign_method, submit_input)
             # recherche du nom 'humain' de l'entité si disponible
@@ -1001,7 +1070,7 @@ function aff_wait()
             log_prefix = "%s -- " % session_id
         else:
             log_prefix = ""
-        log.msg("%s%s" % (log_prefix, _('SAMLResponse (%s) sent to %s') % ('AuthnStatement', sp_ident)))
+        log.msg("%s%s" % (log_prefix, _('SAMLResponse ({0}) sent to {1}').format('AuthnStatement', sp_ident)))
 
         return resp
 
@@ -1053,12 +1122,13 @@ class IDPDiscoveryService(SamlResource):
         try:
             sp_meta = self.manager.get_metadata(idp_ident)
             idp_ident = sp_meta.get('entityID', idp_ident)
-            must_sign_request = is_true(sp_meta['IDPSSODescriptor'].get('WantAuthnRequestsSigned', 'false'))
+            #must_sign_request = is_true(sp_meta['IDPSSODescriptor'].get('WantAuthnRequestsSigned', 'false'))
+            #must_sign_request = is_true(sp_meta['SPSSODescriptor'].get('WantAuthnRequestsSigned', 'false'))
             binding, service_url, consumer_url = get_endpoint(sp_meta, 'SingleSignOnService',
                                                               ent_type='IDPSSODescriptor', allowed_bindings=[samlp.BINDING_HTTP_REDIRECT, samlp.BINDING_HTTP_POST],
                                                               index=endpoint_index)
         except:
-            err_msg = _('no usable endpoint for %s') % idp_ident
+            err_msg = _('no usable endpoint for {0}').format(idp_ident)
             return SamlErrorPage(responsecode.INTERNAL_SERVER_ERROR, err_msg)
         # si ce fournisseur d'identité est désactivé, on n'envoie pas de requête
         # on regarde si la fédération est autorisée pour ce partenaire
@@ -1073,6 +1143,7 @@ class IDPDiscoveryService(SamlResource):
         force_auth = is_true(idp_options.get('force_auth', 'false'))
         is_passive = is_true(idp_options.get('passive', 'false'))
         must_sign_request = idp_options.get('sign_request', None) or must_sign_request
+        must_sign_request = False
         # le niveau d'authentification demandé par défaut est : >= mot de passe protégé (https)
         comparison = idp_options.get('comparison', 'minimum')
         class_ref = idp_options.get('req_context', saml_message.URN_PROTECTED_PASSWORD)
@@ -1117,10 +1188,10 @@ class IDPDiscoveryService(SamlResource):
             relay_info = ""
             if relay_state:
                 relay_info = """
-                    <input type="hidden" name="RelayState" value="%s">""" % relay_state
+                    <input type="hidden" xx name="RelayState" value="%s">""" % relay_state
             if must_sign_request:
                 sign_method_info = """
-                    <input type="hidden" name="SigAlg" value="%s">""" % sign_method
+                    <input type="hidden" xx name="SigAlg" value="%s">""" % sign_method
             form = """%s<br/>
                     <FORM name="form_request" action="%s" method="POST">
                     <input type="hidden" name="SAMLRequest" value="%s">%s%s
@@ -1128,5 +1199,5 @@ class IDPDiscoveryService(SamlResource):
                     </FORM>
             """ % (_('Contacting authentication server'), consumer_url, split_form_arg(saml_request), sign_method_info, relay_info)
             resp = self.set_headers(http.Response(stream = gen_page(_('IDPDiscovery'), form, css)))
-        log.msg(_("Sending SAML authentication request to %s (%s) : %s") % (idp_ident, consumer_url, request_id))
+        log.msg(_("Sending SAML authentication request to {0} ({1}) : {2}").format(idp_ident, consumer_url, request_id))
         return resp
